//
//  Mp3WithID3TagBuilder.swift
//
//  Created by Fabrizio Duroni on 26/02/2018.
//  2018 Fabrizio Duroni.
//

import Foundation

class Mp3WithID3TagBuilder {
    private let id3TagCreator: ID3TagCreator
    private let id3TagConfiguration: ID3TagConfiguration

    init(id3TagCreator: ID3TagCreator, id3TagConfiguration: ID3TagConfiguration) {
        self.id3TagCreator = id3TagCreator
        self.id3TagConfiguration = id3TagConfiguration
    }

    func build(mp3: Data, newId3Tag: ID3Tag, currentId3Tag: ID3Tag?) throws -> Data {
        let tag = try id3TagCreator.create(id3Tag: newId3Tag)
        var tagSizeWithHeader = 0
        if let validCurrentId3Tag = currentId3Tag {
            tagSizeWithHeader = Int(validCurrentId3Tag.properties.size) + ID3TagConfiguration().headerSize();
        }
        let music = mp3.subdata(in: Range(tagSizeWithHeader..<(mp3.count)))
        let mp3WithTag = tag + music
        return mp3WithTag
    }
}
